//------------------------------------------------------
//
//   Greg's Lighting - Main Class
//
//------------------------------------------------------

package gcewing.lighting;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Map;
import java.util.Hashtable;

import net.minecraft.block.*;
import net.minecraft.creativetab.*;
import net.minecraft.entity.player.*;
import net.minecraft.init.*;
import net.minecraft.item.*;
import net.minecraft.item.crafting.*;
import net.minecraft.tileentity.*;
import net.minecraft.world.*;

import net.minecraftforge.common.*;
import net.minecraftforge.oredict.*;
import cpw.mods.fml.common.*;
import cpw.mods.fml.common.network.*;
import cpw.mods.fml.common.registry.*;
import cpw.mods.fml.common.event.*;
import cpw.mods.fml.common.gameevent.*;
import cpw.mods.fml.common.eventhandler.*;

import gcewing.lighting.ic2.*;

@Mod(modid = Info.modID, name = Info.modName, version = Info.versionNumber,
	acceptableRemoteVersions = Info.versionBounds)

public class GregsLighting extends BaseMod<GregsLightingClient> {

	public final static String modName = "GregsLighting";
	
	public final static int guiFloodlightCarbide = 1;
	
	public static BlockFloodlightCarbide floodlightCarbide;
	public static BlockFloodlight floodlight;
	public static BlockFloodlightBeam floodlightBeam;

	public static Item calciumCarbide;
	public static Item bonemealAndCharcoal;
//	public static Item gaslightMantle;
	public static Item gasNozzle;
	public static Item glowingIngot;
		
	public static GregsLighting mod;
	public static boolean ic2Present = false;
	
	public GregsLighting() {
		super();
		mod = this;
		creativeTab = new CreativeTabs("gcewing_lighting:tab") {
			public Item getTabIconItem() {
				return Item.getItemFromBlock(floodlight);
			}
		};
		System.out.printf("GregsLighting: creativeTab = %s\n", creativeTab);
	}
	
	@Override
	GregsLightingClient initClient() {
		return new GregsLightingClient(this);
	}

	@Mod.EventHandler
	public void preInit(FMLPreInitializationEvent e) {
		if (Loader.isModLoaded("IC2")) {
			ic2Present = true;
			GregsLightingIC2.preInit();
		}
		System.out.printf("GregsLighting.preInit: creativeTab = %s\n", creativeTab);
		super.preInit(e);
	}

	@Mod.EventHandler
	public void init(FMLInitializationEvent e) {
		super.init(e);
	}

	@Mod.EventHandler
	public void postInit(FMLPostInitializationEvent e) {
		super.postInit(e);
	}
	
	@Override
	void configure() {
		Floodlight.configure(config);
	}
			
	@Override
	protected void registerBlocks() {
		System.out.printf("GregsLighting.registerBlocks: creativeTab = %s\n", creativeTab);
		floodlightCarbide = newBlock("carbideFloodlight", BlockFloodlightCarbide.class);
		floodlightCarbide.setHardness(1.5F);
		floodlightBeam = newBlock("floodlightBeam", BlockFloodlightBeam.class);
		floodlightBeam.setCreativeTab(null);
		floodlight = newBlock("floodlight", BlockFloodlight.class);
		floodlight.setHardness(1.5F);
		if (ic2Present)
			GregsLightingIC2.registerBlocks();
	}
	
	@Override
	protected void registerItems() {
		calciumCarbide = newItem("calciumCarbide");
		bonemealAndCharcoal = newItem("bonemealAndCharcoal");
		gasNozzle = newItem("gasNozzle");
		glowingIngot = newItem("glowingIngot");
		if (ic2Present)
			GregsLightingIC2.registerItems();
	}

	@Override
	protected void registerRecipes() {
		newShapelessRecipe(bonemealAndCharcoal, 1, new ItemStack(Items.dye, 1, 15), new ItemStack(Items.coal, 1, 1));
		if (config.getBoolean("options", "enableSimpleFloodlight", true)) {
			newRecipe(floodlight, 1, "IrI", "IgI", "GGG",
				'I', Items.iron_ingot, 'r', Items.redstone, 'g', glowingIngot, 'G', Blocks.glass);
			newRecipe(glowingIngot, 1, "GGG", "GgG", "GGG",
				'G', Blocks.glowstone, 'g', Items.gold_nugget);
		}
		newSmeltingRecipe(calciumCarbide, 1, bonemealAndCharcoal);
		newRecipe(gasNozzle, 4, "I", "I",
			'I', Items.iron_ingot);
		newRecipe(floodlightCarbide, 1, "CrC", "CnC", "GGG",
			'C', Blocks.cobblestone, 'r', Items.redstone, 'n', gasNozzle, 'G', Blocks.glass);
		if (ic2Present)
			GregsLightingIC2.registerRecipes();
	}
	
	@Override
	protected void registerContainers() {
		//System.out.printf("GregsLighting.registerContainers\n");
		addContainer(guiFloodlightCarbide, ContainerFLC.class);
	}

	//-----------------------------------------------------------------------------------------
	
	public static void openGuiFloodlightCarbide(World world, int x, int y, int z, EntityPlayer player) {
		//System.out.printf("GregsLighting.openGuiFloodlightCarbide\n");
		mod.openGui(player, guiFloodlightCarbide, world, x, y, z);
	}

//	public static boolean explodeMachineAt(World world, int x, int y, int z) {
//		try {
//			Class<?> mainIC2Class = Class.forName("ic2.common.IC2");
//			mainIC2Class.getMethod("explodeMachineAt", World.class, Integer.TYPE, Integer.TYPE, Integer.TYPE).invoke(null, world, x, y, z);
//			return true;
//		}
//		catch (Exception e) {
//			System.out.printf("GregsLighting.explodeMachineAt: %s\n", e);
//			return false;
//		}
//	}

	//-----------------------------------------------------------------------------------------
	
	@SubscribeEvent
	public void onServerTick(TickEvent.ServerTickEvent e) {
		switch (e.phase) {
			case START:
				Floodlight.performScheduledBeamUpdates();
				break;
		}
	}
	
}
